==> apache-hop-2.8.0-src.tar.gz: apache-hop-2.8.0/core/src/main/java/org/apache/hop/core/util/ExecutorUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.core.util;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.atomic.AtomicInteger;

public class ExecutorUtil {
  public static final String SIMPLE_NAME = ExecutorUtil.class.getSimpleName();
  private static final AtomicInteger threadNum = new AtomicInteger(1);
  private static final ExecutorService executor = init();

  private ExecutorUtil() {}

  private static ExecutorService init() {
    ExecutorService executorService =
        Executors.newCachedThreadPool(
            r -> {
              Thread thread = Executors.defaultThreadFactory().newThread(r);
              thread.setDaemon(true);
              thread.setName(SIMPLE_NAME + " thread " + threadNum.getAndIncrement());
              return thread;
            });
    return executorService;
  }

  public static ExecutorService getExecutor() {
    return executor;
  }
}

==> apache-hop-2.10.0-src.tar.gz: apache-hop-2.10.0/core/src/main/java/org/apache/hop/core/util/ExecutorUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.core.util;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.atomic.AtomicInteger;

public class ExecutorUtil {
  public static final String SIMPLE_NAME = ExecutorUtil.class.getSimpleName();
  private static final AtomicInteger threadNum = new AtomicInteger(1);
  private static final ExecutorService executor = init();

  private ExecutorUtil() {}

  private static ExecutorService init() {
    return Executors.newCachedThreadPool(
        r -> {
          Thread thread = Executors.defaultThreadFactory().newThread(r);
          thread.setDaemon(true);
          thread.setName(SIMPLE_NAME + " thread " + threadNum.getAndIncrement());
          return thread;
        });
  }

  public static ExecutorService getExecutor() {
    return executor;
  }
}
